# Generated by roxygen2: do not edit by hand

export(beamer_presentation2)
export(bookdown_site)
export(bs4_book)
export(bs4_book_theme)
export(build_chapter)
export(calibre)
export(clean_book)
export(context_document2)
export(create_bs4_book)
export(create_gitbook)
export(epub_book)
export(fence_theorems)
export(gitbook)
export(github_document2)
export(html_book)
export(html_chapters)
export(html_document2)
export(html_fragment2)
export(html_notebook2)
export(html_vignette2)
export(ioslides_presentation2)
export(markdown_document2)
export(odt_document2)
export(pdf_book)
export(pdf_document2)
export(powerpoint_presentation2)
export(preview_chapter)
export(publish_book)
export(render_book)
export(resolve_refs_html)
export(rtf_document2)
export(serve_book)
export(slidy_presentation2)
export(tufte_book2)
export(tufte_handout2)
export(tufte_html2)
export(tufte_html_book)
export(word_document2)
import(stats)
import(utils)
importFrom(xfun,dir_create)
importFrom(xfun,dir_exists)
importFrom(xfun,existing_files)
importFrom(xfun,in_dir)
importFrom(xfun,read_utf8)
importFrom(xfun,same_path)
importFrom(xfun,sans_ext)
importFrom(xfun,with_ext)
importFrom(xfun,write_utf8)
